@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,8 +14,13 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
+#ifndef __pyg_convertors_h__
+#define __pyg_convertors_h__
+
 /* Python includes */
 #include <Python.h>
 
@@ -24,6 +29,8 @@
 
 #include <limits.h>
 
+#include "misc.h"
+
 /* Needed for Python 2.3, 2.4 has same included */
 #ifndef Py_RETURN_NONE
 #  define Py_RETURN_NONE return Py_INCREF(Py_None), Py_None
@@ -97,7 +104,7 @@ PyObject *UnicodeStringToPythonL(const unsigned char *src, const int len);
 /**
  * Converts locale encoded string to python unicode string.
  */
-PyObject *LocaleStringToPython(char *src);
+PyObject *LocaleStringToPython(const char *src);
 
 /**
  * Converts string to CategoryType.
@@ -167,7 +174,7 @@ char *GetCharFromDict(PyObject *dict, char *key);
 /**
  * Gets char* with length (may contain NULs) from dictionary dict with key key. (doesn't allocate it!)
  */
-char *GetDataFromDict(PyObject *dict, char *key, int *len);
+char *GetDataFromDict(PyObject *dict, char *key, Py_ssize_t *len);
 
 /**
  * Gets GSM_MemoryType from dictionary dict with key key.
@@ -179,6 +186,11 @@ GSM_MemoryType GetMemoryTypeFromDict(PyObject *dict, char *key);
  */
 PyObject *CBToPython(GSM_CBMessage *cb);
 
+/**
+ * Coverts USSD message to Python object.
+ */
+PyObject *USSDToPython(GSM_USSDMessage *ussd);
+
 /**
  * Converts SMSValidity to string.
  */
@@ -378,3 +390,5 @@ PyObject *WAPBookmarkToPython(GSM_WAPBookmark *wap);
  * Converts WAP bookmark from Python object.
  */
 int WAPBookmarkFromPython(PyObject* dict, GSM_WAPBookmark *wap);
+
+#endif
