@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,10 +14,13 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
 /* SMS related conversions */
 
+#include "pyg-config.h"
 #include "convertors.h"
 #include "misc.h"
 
@@ -611,6 +614,7 @@ int SMSFromPython(PyObject *dict, GSM_SMSMessage *sms, int needslocation, int ne
     }
 
     memset(sms, 0, sizeof(sms));
+    GSM_SetDefaultSMSData(sms);
 
     o = PyDict_GetItemString(dict, "SMSC");
     if (o == NULL) {
@@ -992,9 +996,9 @@ int MultiSMSFromPython(PyObject *list, GSM_MultiSMSMessage *sms) {
 
     len = PyList_Size(list);
 
-    if (len > MAX_MULTI_SMS) {
-        pyg_warning("Truncating MultiSMS entries to %d entries! (from %d))\n", MAX_MULTI_SMS, len);
-        len = MAX_MULTI_SMS;
+    if (len > GSM_MAX_MULTI_SMS) {
+        pyg_warning("Truncating MultiSMS entries to %d entries! (from %d))\n", GSM_MAX_MULTI_SMS, len);
+        len = GSM_MAX_MULTI_SMS;
     }
     sms->Number = len;
 
@@ -1304,7 +1308,7 @@ EncodeMultiPartSMSID StringToMultiPartSMSID(char *s){
     return 0;
 }
 
-PyObject *SMSPartToPython(MultiPartSMSEntry *entry) {
+PyObject *SMSPartToPython(GSM_MultiPartSMSEntry *entry) {
     char        *t;
     PyObject    *r;
     PyObject    *v;
@@ -1509,7 +1513,7 @@ PyObject *SMSInfoToPython(GSM_MultiPartSMSInfo *smsinfo) {
 }
 
 
-int SMSPartFromPython(PyObject *dict, MultiPartSMSEntry *entry) {
+int SMSPartFromPython(PyObject *dict, GSM_MultiPartSMSEntry *entry) {
     char            *s;
     int             i;
     PyObject        *o;
@@ -1771,9 +1775,9 @@ int SMSInfoFromPython(PyObject *dict, GSM_MultiPartSMSInfo *entry) {
 
     len = PyList_Size(o);
 
-    if (len > MAX_MULTI_SMS - 1) {
-        pyg_warning("Too many entries, truncating from %d to %d\n", len, MAX_MULTI_SMS - 1);
-        len = MAX_MULTI_SMS - 1;
+    if (len > GSM_MAX_MULTI_SMS - 1) {
+        pyg_warning("Too many entries, truncating from %d to %d\n", len, GSM_MAX_MULTI_SMS - 1);
+        len = GSM_MAX_MULTI_SMS - 1;
     }
 
     entry->EntriesNum = len;
