@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,8 +14,11 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
+#include "pyg-config.h"
 #include "errors.h"
 #include "convertors.h"
 
@@ -72,12 +75,13 @@ PyObject *PyERR_GNAPPLETWRONG;
 PyObject *PyERR_FOLDERPART;
 PyObject *PyERR_FOLDERNOTEMPTY;
 PyObject *PyERR_DATACONVERTED;
+PyObject *PyERR_UNCONFIGURED;
 
 int checkError(GSM_StateMachine *s, GSM_Error error, char *where) {
     PyObject    *val;
     PyObject    *text;
     PyObject    *err = GammuError;
-    char        *msg;
+    const char  *msg;
 
     switch (error) {
         case ERR_NONE: return 1;
@@ -133,13 +137,10 @@ int checkError(GSM_StateMachine *s, GSM_Error error, char *where) {
         case ERR_FOLDERPART: err = PyERR_FOLDERPART; break;
         case ERR_FOLDERNOTEMPTY: err = PyERR_FOLDERNOTEMPTY; break;
         case ERR_DATACONVERTED: err = PyERR_DATACONVERTED; break;
+        case ERR_UNCONFIGURED: err = PyERR_UNCONFIGURED; break;
     }
 
-    if (s == NULL) {
-        msg = (char *)print_error(error, di.df, NULL);
-    } else {
-        msg = (char *)print_error(error, s->di.df, s->msg);
-    }
+    msg = GSM_ErrorString(error);
 
     text = LocaleStringToPython(msg);
     if (text == NULL) {
@@ -164,7 +165,7 @@ int checkError(GSM_StateMachine *s, GSM_Error error, char *where) {
 
 #define CREATE_ERROR(x) \
     /* Help text */ \
-    help_text = PyString_FromFormat("Exception corresponding to gammu error " #x ".\nVerbose error description: %s", print_error(x, NULL, 0)); \
+    help_text = PyString_FromFormat("Exception corresponding to gammu error " #x ".\nVerbose error description: %s", GSM_ErrorString(x)); \
     if (help_text == NULL) \
         return 0; \
     error_dict = PyDict_New(); \
@@ -274,6 +275,7 @@ int gammu_create_errors(PyObject *d) {
     CREATE_ERROR(ERR_FOLDERPART)
     CREATE_ERROR(ERR_FOLDERNOTEMPTY)
     CREATE_ERROR(ERR_DATACONVERTED)
+    CREATE_ERROR(ERR_UNCONFIGURED)
 
     PyDict_SetItemString(d, "Errors", error_list);
     Py_DECREF(error_list);
