@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (c) 2003 - 2006 Michal Čihař
+ * Copyright (c) 2003 - 2007 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -14,8 +14,16 @@
  * You should have received a copy of the GNU General Public License along with
  * this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ *
+ * vim: expandtab sw=4 ts=4 sts=4:
  */
 
+#ifndef __pyg_misc_h__
+#define __pyg_misc_h__
+
+/* Python includes */
+#include <Python.h>
+
 /**
  * Copies at most n chars from src to dest, dest will be \0 terminated.
  */
@@ -23,3 +31,11 @@ char *mystrncpy(char *dest, const char *src, size_t n);
 
 #define pyg_error(...) printf("python-gammu: ERROR: " __VA_ARGS__)
 #define pyg_warning(...) printf("python-gammu: WARNING: " __VA_ARGS__)
+
+
+/* Compatiblity with older python releases */
+#if PY_VERSION_HEX < 0x02050000
+typedef int Py_ssize_t;
+#endif
+
+#endif
